summaryrefslogtreecommitdiffstats
path: root/src/gui/editors/parameters/RosegardenParameterArea.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/editors/parameters/RosegardenParameterArea.cpp')
-rw-r--r--src/gui/editors/parameters/RosegardenParameterArea.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/gui/editors/parameters/RosegardenParameterArea.cpp b/src/gui/editors/parameters/RosegardenParameterArea.cpp
index 8790122..1fc924e 100644
--- a/src/gui/editors/parameters/RosegardenParameterArea.cpp
+++ b/src/gui/editors/parameters/RosegardenParameterArea.cpp
@@ -46,11 +46,11 @@
namespace Rosegarden
{
-RosegardenParameterArea::RosegardenParameterArea(TQWidget *parent,
+RosegardenParameterArea::RosegardenParameterArea(TQWidget *tqparent,
const char *name, WFlags f)
- : TQWidgetStack(parent, name, f),
+ : TQWidgetStack(tqparent, name, f),
m_style(RosegardenParameterArea::CLASSIC_STYLE),
- m_scrollView(new TQScrollView(this, 0, Qt::WStaticContents)),
+ m_scrollView(new TQScrollView(this, 0, TQt::WStaticContents)),
m_classic(new TQVBox(m_scrollView->viewport())),
m_tabBox(new KTabWidget(this)),
m_active(0),
@@ -86,15 +86,15 @@ void RosegardenParameterArea::addRosegardenParameterBox(
m_parameterBoxes.push_back(b);
m_scrollView->setMinimumWidth(std::max(m_scrollView->minimumWidth(),
- b->sizeHint().width()) + 8);
+ b->tqsizeHint().width()) + 8);
- // Create a titled group box for the parameter box, parented by the
- // classic layout widget, so that it can be used to provide a title
+ // Create a titled group box for the parameter box, tqparented by the
+ // classic tqlayout widget, so that it can be used to provide a title
// and outline, in classic mode. Add this container to an array that
// parallels the above array of parameter boxes.
TQVGroupBox *box = new TQVGroupBox(b->getLongLabel(), m_classic);
- box->layout()->setMargin( 4 ); // about half the default value
+ box->tqlayout()->setMargin( 4 ); // about half the default value
TQFont f;
f.setBold( true );
box->setFont( f );
@@ -204,7 +204,7 @@ void RosegardenParameterArea::moveWidget(TQWidget *old_container,
m_tabBox->removePage(box);
}
- // Reparent the parameter box, and perform any container-specific
+ // Retqparent the parameter box, and perform any container-specific
// configuration.
if (new_container == m_classic) {